OpusPacketUtils class abstract

Bundles utility functions to examine opus packets.

All methods copy the input data into native memory.

Constructors

OpusPacketUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getBandwidth({required Uint8List packet}) → int
Returns the bandwidth from a packet
getChannelCount({required Uint8List packet}) → int
Returns the channel count from a packet
getFrameCount({required Uint8List packet}) → int
Returns the amount of frames in a packet.
getSampleCount({required Uint8List packet, required int sampleRate}) → int
Returns the amount of samples in a packet given a sampleRate.
getSamplesPerFrame({required Uint8List packet, required int sampleRate}) → int
Returns the amount of samples per frame in a packet given a sampleRate.