opus_encoder_ctl method
Perform a CTL function on an Opus encoder.
Generally the request and subsequent arguments are generated by a convenience macro.
st is the OpusEncoder* encoder state.
request and all remaining parameters should be replaced by one
of the convenience macros in opus_genericctls or
opus_encoderctls.
Implementation
@override
int opus_encoder_ctl(
ffi.Pointer<OpusEncoder> st,
int request,
int va,
) {
return _opus_encoder_ctl(
st,
request,
va,
);
}