Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
opus_decode(Pointer<OpusDecoder> st, Pointer<Uint8> data, int len, Pointer<Int16> pcm, int frame_size, int decode_fec)
→ int
-
-
opus_decode_float(Pointer<OpusDecoder> st, Pointer<Uint8> data, int len, Pointer<Float> pcm, int frame_size, int decode_fec)
→ int
-
-
opus_decoder_create(int Fs, int channels, Pointer<Int32> error)
→ Pointer<OpusDecoder>
-
-
opus_decoder_destroy(Pointer<OpusDecoder> st)
→ void
-
-
opus_decoder_get_nb_samples(Pointer<OpusDecoder> dec, Pointer<Uint8> packet, int len)
→ int
-
-
opus_decoder_get_size(int channels)
→ int
-
-
opus_decoder_init(Pointer<OpusDecoder> st, int Fs, int channels)
→ int
-
-
opus_packet_get_bandwidth(Pointer<Uint8> data)
→ int
-
-
opus_packet_get_nb_channels(Pointer<Uint8> data)
→ int
-
-
opus_packet_get_nb_frames(Pointer<Uint8> packet, int len)
→ int
-
-
opus_packet_get_nb_samples(Pointer<Uint8> packet, int len, int Fs)
→ int
-
-
opus_packet_get_samples_per_frame(Pointer<Uint8> data, int Fs)
→ int
-
-
opus_packet_parse(Pointer<Uint8> data, int len, Pointer<Uint8> out_toc, Pointer<Uint8> frames, int size, Pointer<Int32> payload_offset)
→ int
-
-
opus_pcm_soft_clip(Pointer<Float> pcm, int frame_size, int channels, Pointer<Float> softclip_mem)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited