Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
opus_encode(Pointer<OpusEncoder> st, Pointer<Int16> pcm, int frame_size, Pointer<Uint8> data, int max_data_bytes)
→ int
-
-
opus_encode_float(Pointer<OpusEncoder> st, Pointer<Float> pcm, int frame_size, Pointer<Uint8> data, int max_data_bytes)
→ int
-
-
opus_encoder_create(int Fs, int channels, int application, Pointer<Int32> error)
→ Pointer<OpusEncoder>
-
-
opus_encoder_ctl(Pointer<OpusEncoder> st, int request, int va)
→ int
-
-
opus_encoder_destroy(Pointer<OpusEncoder> st)
→ void
-
-
opus_encoder_get_size(int channels)
→ int
-
-
opus_encoder_init(Pointer<OpusEncoder> st, int Fs, int channels, int application)
→ int
-
-
toString()
→ String
-
A string representation of this object.
inherited